@@ -111,3 +111,18 @@ typedef struct ImageInfoPSDStruct
 #define TIFF_COMPRESSION_SGILOG        34676
 #define TIFF_COMPRESSION_SGILOG24      34677
 #define TIFF_COMPRESSION_JP2000        34712
+
+
+#define JPEG_TYPE_BASELINE                     0xC0
+#define JPEG_TYPE_EXTENDED_SEQUENTIAL          0xC1
+#define JPEG_TYPE_PROGRESSIVE                  0xC2
+#define JPEG_TYPE_LOSSLESS                     0xC3
+#define JPEG_TYPE_DIFFERENTIAL_SEQUENTIAL      0xC5
+#define JPEG_TYPE_DIFFERENTIAL_PROGRESSIVE     0xC6
+#define JPEG_TYPE_DIFFERENTIAL_LOSSLESS        0xC7
+#define JPEG_TYPE_EXTENDED_SEQUENTIAL_AC       0xC9
+#define JPEG_TYPE_PROGRESSIVE_AC               0xCA
+#define JPEG_TYPE_LOSSLESS_AC                  0xCB
+#define JPEG_TYPE_DIFFERENTIAL_SEQUENTIAL_AC   0xCD
+#define JPEG_TYPE_DIFFERENTIAL_PROGRESSIVE_AC  0xCE
+#define JPEG_TYPE_DIFFERENTIAL_LOSSLESS_AC     0xCF
